var textureSquirrel    = PIXI.Texture.fromImage('./images/squirr.png');
var textureBranchRight = PIXI.Texture.fromImage('./images/treeRight.png');
var textureBranchLeft  = PIXI.Texture.fromImage('./images/branch.png');
var textureBeer        = PIXI.Texture.fromImage('./images/beer.png');
var texturePorcupine   = PIXI.Texture.fromImage('./images/pork.png');
var textureHole        = PIXI.Texture.fromImage('./images/hole.png');

var textures = [textureSquirrel, textureBranchLeft, textureBranchRight, textureBeer, texturePorcupine, textureHole];

textures.forEach(texture => texture.baseTexture.scaleMode = PIXI.SCALE_MODES.NEAREST);

function Obstacle(x,y) {
	this.obstacleType = Math.floor(Math.random() * 6)

	this.determineLane = function(){

		if (this.obstacleType === 1) {
			//left branch
			return {
				0: true,
				1: true,
				2: false
			}
		} else if (this.obstacleType === 2) {
			//right branch
			return {
				0: false,
				1: true,
				2: true
			}
		} else {
			return Math.floor(Math.random() * 3);
		}
	}

	this.determineX = function(){
		if (this.obstacleType === 1) {
			return 170
		} else if (this.obstacleType === 2) {
			return 330
		} else {
			return (125 + 42) + (this.lane) * 84
		}
	}

	this.determineZ = function(){
		if (this.obstacleType === 1 || this.obstacleType === 2) {
			// branches go over the head of our guy, whose z index is 10
			return 11
		} else {
			return 5
		}
	}

	this.lane = this.determineLane(); 
	this.x = x/2;
	this.y = y + 200;
	this.ob = new PIXI.Sprite(textures[this.obstacleType]);
	this.ob.anchor.set(0.5, 1);
	this.ob.scale.set(.5);
	this.ob.zIndex = this.determineZ();



	this.ob.x = this.determineX();
	this.ob.y = this.y;

	this.update = function(velocity) {
		this.ob.y -= velocity;
	}

	this.show = function() {
		return this.ob;
	}

	this.hits = function(target) {

		if (this.ob.x && this.ob.y) {
			if (!(this.ob.y > target.height + target.y || this.ob.y + this.ob.height < target.y + 80)) {

				// handle obstacles that take up more than 1 lane
				if (typeof this.lane === 'object') {
					if (this.lane[target.lane - 2]) {
						// for trees, laying back prevents you from hitting them
						if (target.stateOfAnimation !== "lay") {
							target.collided = true;
							return true;
						} 
					}

				// handle obstacles that only take up 1 lane
				} else {
					if (this.lane === target.lane - 2) {
						target.collided = true;
						return true;
					}
				}
			}
		}
		return false;
	}

	this.offscreen = function() {
		if (this.ob.y < 0) {
			return true;
		} else {
			return false;
		}
	}

}